==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/ClockSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClockSpecFluentImpl<A extends ClockSpecFluent<A>> extends BaseFluent<A> implements ClockSpecFluent<A>{
  public ClockSpecFluentImpl() {
  }
  public ClockSpecFluentImpl(ClockSpec instance) {
    this.withClockIdsSlice(instance.getClockIdsSlice()); 
    this.withPid(instance.getPid()); 
    this.withTimeOffset(instance.getTimeOffset()); 
  }
  private String clockIdsSlice;
  private Integer pid;
  private String timeOffset;
  public String getClockIdsSlice() {
    return this.clockIdsSlice;
  }
  public A withClockIdsSlice(String clockIdsSlice) {
    this.clockIdsSlice=clockIdsSlice; return (A) this;
  }
  public Boolean hasClockIdsSlice() {
    return this.clockIdsSlice != null;
  }
  public Integer getPid() {
    return this.pid;
  }
  public A withPid(Integer pid) {
    this.pid=pid; return (A) this;
  }
  public Boolean hasPid() {
    return this.pid != null;
  }
  public String getTimeOffset() {
    return this.timeOffset;
  }
  public A withTimeOffset(String timeOffset) {
    this.timeOffset=timeOffset; return (A) this;
  }
  public Boolean hasTimeOffset() {
    return this.timeOffset != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClockSpecFluentImpl that = (ClockSpecFluentImpl) o;
    if (clockIdsSlice != null ? !clockIdsSlice.equals(that.clockIdsSlice) :that.clockIdsSlice != null) return false;
    if (pid != null ? !pid.equals(that.pid) :that.pid != null) return false;
    if (timeOffset != null ? !timeOffset.equals(that.timeOffset) :that.timeOffset != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clockIdsSlice,  pid,  timeOffset,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clockIdsSlice != null) { sb.append("clockIdsSlice:"); sb.append(clockIdsSlice + ","); }
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (timeOffset != null) { sb.append("timeOffset:"); sb.append(timeOffset); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/ClockSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClockSpecFluentImpl<A extends ClockSpecFluent<A>> extends BaseFluent<A> implements ClockSpecFluent<A>{
  public ClockSpecFluentImpl() {
  }
  public ClockSpecFluentImpl(ClockSpec instance) {
    if (instance != null) {
      this.withClockIdsSlice(instance.getClockIdsSlice());
      this.withPid(instance.getPid());
      this.withTimeOffset(instance.getTimeOffset());
    }
  }
  private String clockIdsSlice;
  private Integer pid;
  private String timeOffset;
  public String getClockIdsSlice() {
    return this.clockIdsSlice;
  }
  public A withClockIdsSlice(String clockIdsSlice) {
    this.clockIdsSlice=clockIdsSlice; return (A) this;
  }
  public Boolean hasClockIdsSlice() {
    return this.clockIdsSlice != null;
  }
  public Integer getPid() {
    return this.pid;
  }
  public A withPid(Integer pid) {
    this.pid=pid; return (A) this;
  }
  public Boolean hasPid() {
    return this.pid != null;
  }
  public String getTimeOffset() {
    return this.timeOffset;
  }
  public A withTimeOffset(String timeOffset) {
    this.timeOffset=timeOffset; return (A) this;
  }
  public Boolean hasTimeOffset() {
    return this.timeOffset != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClockSpecFluentImpl that = (ClockSpecFluentImpl) o;
    if (!java.util.Objects.equals(clockIdsSlice, that.clockIdsSlice)) return false;

    if (!java.util.Objects.equals(pid, that.pid)) return false;

    if (!java.util.Objects.equals(timeOffset, that.timeOffset)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clockIdsSlice,  pid,  timeOffset,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clockIdsSlice != null) { sb.append("clockIdsSlice:"); sb.append(clockIdsSlice + ","); }
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (timeOffset != null) { sb.append("timeOffset:"); sb.append(timeOffset); }
    sb.append("}");
    return sb.toString();
  }
  
}
